@@ -9,13 +9,10 @@ def count_bits(number):
     Counts the number of '1' bits in the binary
     representation of the given integer
 
-    *Parameters*
-    number:
-      number to count the '1' bits of
-
-    *Returns*
-    count: int
-      number of bits that are '1'
+    :param number: Number to count the '1' bits of
+    :type number: int
+    :return: Number of bits that are '1'
+    :rtype: int
     """
     bits = 0
     shifted_number = number
@@ -30,13 +27,11 @@ def get_mask_min_bit(mask):
     Calculate the position of the Lowest order bit that
     is '1'
 
-    *Parameters*
-    mask:
-      mask of which the position of the lowest order bit should be found in
-
-    *Returns*
-    min_bit: int
-      index (starting with 0) of the lowest order bit that is '1'
+    :param mask: Mask of which the position of the lowest order bit should
+        be found in
+    :type mask: int
+    :return: Index (starting with 0) of the lowest order bit that is '1'
+    :rtype: int
     """
     min_bit = 0
     while mask & 1 == 0:
@@ -46,6 +41,11 @@ def get_mask_min_bit(mask):
 
 
 class ROCv3():
+    """
+    Responsible for handling all interaction with the ROCs. Effectively wraps
+    the ROC hardware interface.
+    """
+
     def __init__(
             self,
             transport,
@@ -57,19 +57,22 @@ class ROCv3():
         Software counterpart of the HGCROCv3 ASIC to be used with the test
         systems
 
-        *Parameters*
-        transport
-          object that encapsulates how to write and read to the
-          physical chip
-        path_to_file
-          path to the csv file containing the definition of the registers
-          and parameters
+        :param transport: Object that encapsulates how to write and read to the
+            physical chip
+        :type transport: object
+        :param base_address: Base address of the ROC to read and write to
+        :type base_address: int
+        :param name: Name of the ROC
+        :type name: str
+        :param reset_pin: i2c pin responsible for resetting the ROC
+        :type reset_pin: object
+        :param path_to_file: Path to the csv file containing the definition of
+            the registers and parameters
+        :type path_to_file: str
         """
         self.transaction_logger = logging.getLogger(f'{name}')
         self.transaction_logger.info(f'Initializing {name}'
                                      f' at base address {base_address}')
-        self.validated = False
-        self.translated = False
         self.validation_config = {}
         self.translation_dict = {}
         self.cache = {}
@@ -130,27 +133,29 @@ class ROCv3():
 
         # release the roc from reset
         self.reset_pin.write(1)
+        self.transaction_logger.info("Initialization complete")
 
-    def _validate(self, config: dict, reference: dict = None, read=False):
+    def _validate(self, config: dict, reference: dict = None, read=False,
+                  log_message_written=False):
         """
         Check if the configuration given in config only contains
         valid keys and values within the specified range
 
-        Parameters
-        ==========
-        config
-          The configuration that is to be checked (in the case of a recursive
-          call, the relevant subsection is normally passed in)
-        reference
-          the reference that the configuration is checked against, this is
-          needed as the function is recursive and so needs to pass the correct
-          section of the total reference configuration to the function call
-          checking the sub-section, this parameter defaults to the full
-          reference so the user should not specify it
+        :param config: The configuration that is to be checked (in the case of
+            a recursive call, the relevant subsection is normally passed in)
+        :type config: dict
+        :param reference: The reference that the configuration is checked
+            against, this is needed as the function is recursive and so needs
+            to pass the correct section of the total reference configuration
+            to the function call checking the sub-section, this parameter
+            defaults to the full reference so the user should not specify it
+        :type reference: dict
+        :param read: Specifies if the configuration is for reading or writing
+        :type read: bool, optional
         """
-        if self.validated is False:
-            self.transaction_logger.info("Validating configuration dictionary")
-            self.validated = True
+        if not log_message_written:
+            self.transaction_logger.debug(
+                "Validating configuration dictionary")
 
         if reference is None:
             reference = self.validation_config
@@ -159,7 +164,7 @@ class ROCv3():
                     and key in reference:
                 try:
                     self._validate(config[key], reference=reference[key],
-                                   read=read)
+                                   read=read, log_message_written=True)
                 except KeyError as e:
                     message = e.args[0] + f" in {key}"
                     raise KeyError(message)
@@ -180,11 +185,11 @@ class ROCv3():
 
     def _translate(self, valid_config: dict,
                    translation_dictionary=None,
-                   registers=[]) -> list:
-        if self.translated is False:
-            self.transaction_logger.info("Translating configuration "
-                                         "dictionary")
-            self.translated = True
+                   registers=[],
+                   transaction_log_written=False) -> list:
+        if not transaction_log_written:
+            self.transaction_logger.debug(
+                "Translating configuration dictionary")
 
         if translation_dictionary is None:
             translation_dictionary = self.translation_dict
@@ -192,7 +197,8 @@ class ROCv3():
             if isinstance(val, dict):
                 self._translate(val,
                                 translation_dictionary[key],
-                                registers)
+                                registers,
+                                transaction_log_written=True)
             else:
                 param_registers = translation_dictionary[key].keys()
                 masks = translation_dictionary[key].values()
@@ -205,7 +211,10 @@ class ROCv3():
         return registers
 
     def _translate_read(self, valid_config, translation_dictionary=None,
-                        curr_key=[], param_reg_pairs=[]):
+                        curr_key=[], param_reg_pairs=[],
+                        written_log_message=False):
+        if not written_log_message:
+            self.transaction_logger.debug('Translating Read Config')
         if translation_dictionary is None:
             translation_dictionary = self.translation_dict
         for key, val in valid_config.items():
@@ -216,7 +225,8 @@ class ROCv3():
                         val,
                         translation_dictionary[key],
                         curr_key=level_down_key,
-                        param_reg_pairs=param_reg_pairs)
+                        param_reg_pairs=param_reg_pairs,
+                        written_log_message=True)
             else:
                 new_key = curr_key.copy()
                 new_key.append(key)
@@ -245,6 +255,15 @@ class ROCv3():
         return write_registers
 
     def configure(self, configuration: dict, readback=False):
+        """
+        Writes to ROC registers
+
+        :param configuration: Configuration containing values to write
+        :type configuration: dict
+        :param readback: Specifies whether to check written registers
+            against cache. Defaults to False
+        :type readback: bool, optional
+        """
         try:
             self._validate(configuration)
         except KeyError as err:
@@ -253,6 +272,8 @@ class ROCv3():
             raise ValueError(str(err.args[0]) + f" in ROC {self.name}")
         register_updates = self._translate(configuration)
         register_writes = self._cache(register_updates)
+        self.transaction_logger.info("Updating configuration in "
+                                     f'{len(register_writes)} registers')
         for reg in register_writes:
             try:
                 self.transport.write(self.base_address, reg[0])
@@ -270,8 +291,18 @@ class ROCv3():
                 raise IOError(
                         str(err.args[0]) +
                         f" during write operation to {self.name}")
+        self.transaction_logger.info('Configuration written to '
+                                     f'{len(register_writes)} registers')
 
     def read(self, configuration):
+        """
+        Reads register values from cache
+
+        :param configuration: Configuration containing parameters to read
+        :type configuration: dict
+        :return: The values of parameters read from cache
+        :rtype: dict
+        """
         try:
             self._validate(configuration, read=True)
         except KeyError as err:
@@ -281,6 +312,8 @@ class ROCv3():
         parameters_to_be_read = self._translate_read(configuration,
                                                      param_reg_pairs=[])
         parameters = []
+        self.transaction_logger.info(f'Reading {len(parameters_to_be_read)} '
+                                     'parameters')
         # read the values from the registers
         for param, reglist in parameters_to_be_read:
             parameter_value = 0
@@ -298,6 +331,8 @@ class ROCv3():
         for keylist, value in parameters:
             subdict = dict_utils.nested_dict_from_keylist(keylist, value)
             dict_utils.update_dict(result, subdict, in_place=True)
+        self.transaction_logger.info(f'{len(parameters_to_be_read)} parameters'
+                                     'read from cache')
         return result
 
     def reset_cache(self):
@@ -311,11 +346,17 @@ class ROCv3():
         self.reset_cache()
         self.reset_pin.write(1)
 
-    def describe(self, validation_config: dict = None):
+    def describe(self, _validation_config: dict = None):
+        """
+        Read the parameter description from the ROC register map
+
+        :return: The ROC description with min and max parameter values
+        :rtype: dict
+        """
         roc_dict = {}
-        if validation_config is None:
-            validation_config = self.validation_config
-        for key, value in validation_config.items():
+        if _validation_config is None:
+            _validation_config = self.validation_config
+        for key, value in _validation_config.items():
             if isinstance(value, dict):
                 roc_dict[key] = self.describe(value)
             elif isinstance(value, tuple):
