@@ -224,33 +224,36 @@ def test_zmq_i2c_server(patched_io):
     def proc_run_server():
         logging.basicConfig(filename='roc_configuration.log')
         config_table = 'regmaps/HGCROC3_I2C_params_regmap.csv'
-        socket = server.open_socket(5555)
-        server.run(config_table, socket)
+        test_server = server.Server(5555, config_table)
+        test_server.run()
 
     proc = mp.Process(target=proc_run_server)
     proc.start()
 
-    time.sleep(2)
     context = zmq.Context()
     socket = context.socket(zmq.REQ)
     socket.connect("tcp://localhost:5555")
 
-    socket.send_string(str(yaml.dump(sendset)))
-    socket.recv()
+    socket.send_string(yaml.dump(sendset))
+    resp = socket.recv_string()
+    resp = yaml.safe_load(resp)
+    assert resp['status'] == 'success'
+    assert resp['type'] == 'set'
+    expected_get_response = sendset['args']
 
     socket.send_string(str(yaml.dump(sendget)))
     recv = yaml.safe_load(socket.recv())
-    assert config == recv['args']
+    assert recv['args'] == expected_get_response
 
-    socket.send_string(str(yaml.dump(sendempty)))
+    socket.send_string(yaml.dump(sendempty))
     recv = yaml.safe_load(socket.recv())
-    assert recv['status'] == 'error'
-
     socket.send_string(str(yaml.dump({'type': 'stop',
                                       'status': 'send',
                                       'args': {}})))
     socket.recv()
 
+    assert recv['status'] == 'error'
+
     return
 
 
@@ -264,8 +267,8 @@ def test_describe_type(patched_io):
     def proc_run_server():
         logging.basicConfig(filename='roc_configuration.log')
         config_table = 'regmaps/HGCROC3_I2C_params_regmap.csv'
-        socket = server.open_socket(5555)
-        server.run(config_table, socket)
+        test_server = server.Server(5555, config_table)
+        test_server.run()
 
     proc = mp.Process(target=proc_run_server)
     proc.start()
@@ -275,13 +278,13 @@ def test_describe_type(patched_io):
     socket = context.socket(zmq.REQ)
     socket.connect("tcp://localhost:5555")
 
-    socket.send_string(str(yaml.dump(send)))
+    socket.send_string(yaml.dump(send))
     recv = yaml.safe_load(socket.recv())
-    assert recv['args'] == expected_recv
-
     socket.send_string(str(yaml.dump({'type': 'stop',
                                       'status': 'send',
                                       'args': {}})))
     socket.recv()
 
+    assert recv['args'] == expected_recv
+
     return
